@@ -1,4 +1,4 @@
-#!C:\perl\bin\perl.exe
+#!/usr/bin/perl -w
 package Net::BitTorrent::Torrent::Tracker;
 {
     use strict;
@@ -9,14 +9,9 @@ package Net::BitTorrent::Torrent::Tracker;
     use lib q[./../../../];
     use Net::BitTorrent::Torrent::Tracker::HTTP;
     use Net::BitTorrent::Torrent::Tracker::UDP;
-
-    #
     use version qw[qv];
-    our $SVN = q[$Id: Tracker.pm 34 2008-11-20 03:38:52Z sanko@cpan.org $];
-    our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 34 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
-
-    #
-    my (@CONTENTS) = \my (%torrent, %_urls, %complete, %incomplete);
+    our $VERSION_BASE = 49; our $UNSTABLE_RELEASE = 3; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new(($VERSION_BASE))->numify / 1000), $UNSTABLE_RELEASE);
+    my (@CONTENTS) = \my (%torrent, %urls);
     my %REGISTRY;
 
     sub new {
@@ -44,61 +39,47 @@ package Net::BitTorrent::Torrent::Tracker;
         $self = bless(\$args->{q[URLs]}->[0], $class);
         $torrent{refaddr $self} = $args->{q[Torrent]};
         weaken $torrent{refaddr $self};
-        $complete{refaddr $self}   = 0;
-        $incomplete{refaddr $self} = 0;
-        $_urls{refaddr $self}      = [];
+        $urls{refaddr $self} = [];
         for my $_url (@{$args->{q[URLs]}}) {
-            push @{$_urls{refaddr $self}},
+            push @{$urls{refaddr $self}},
                 ($_url =~ m[^http://]i
                  ? q[Net::BitTorrent::Torrent::Tracker::HTTP]
                  : q[Net::BitTorrent::Torrent::Tracker::UDP]
                 )->new({URL => $_url, Tier => $self});
         }
-        $torrent{refaddr $self}->_client->_schedule({Time   => time,
-                                                     Code   => \&_announce,
-                                                     Object => $self
-                                                    }
-        ) if defined $torrent{refaddr $self}->_client;
         weaken($REGISTRY{refaddr $self} = $self);
-        @{$_urls{refaddr $self}} = shuffle(@{$_urls{refaddr $self}});
+        @{$urls{refaddr $self}} = shuffle(@{$urls{refaddr $self}});
         return $self;
     }
 
     # Accessors | Public
-    sub incomplete { return $incomplete{refaddr +shift} }
-    sub complete   { return $complete{refaddr +shift} }
+    sub urls { return $urls{refaddr +shift}; }
 
     # Accessors | Private
     sub _client  { return $torrent{refaddr +shift}->_client; }
     sub _torrent { return $torrent{refaddr +shift}; }
-    sub _urls    { return $_urls{refaddr +shift}; }
+
+    sub _nodes {
+        my ($self) = @_;
+        return compact(map { $_->_nodes } @{$urls{refaddr $self}});
+    }
 
     # Methods | Private
-    sub _set_complete {
-        my ($self, $value) = @_;
-        return $complete{refaddr $self} = $value;
-    }
-
-    sub _set_incomplete {
-        my ($self, $value) = @_;
-        return $incomplete{refaddr $self} = $value;
-    }
-
     sub _shuffle {
         my ($self) = @_;
         return (
-             push(@{$_urls{refaddr $self}}, shift(@{$_urls{refaddr $self}})));
+               push(@{$urls{refaddr $self}}, shift(@{$urls{refaddr $self}})));
     }
 
     sub _announce {
-        my ($self) = @_;
+        my ($self, $event) = @_;
         return if not defined $self;
-        return if not defined $_urls{refaddr $self};
-        return if not scalar @{$_urls{refaddr $self}};
-        return $_urls{refaddr $self}->[0]->_announce(q[started]);
+        return if not defined $urls{refaddr $self};
+        return if not scalar @{$urls{refaddr $self}};
+        return $urls{refaddr $self}->[0]->_announce($event ? $event : ());
     }
 
-    sub _as_string {
+    sub as_string {
         my ($self, $advanced) = @_;
         my $dump = !$advanced ? $$self : sprintf <<'END',
 Net::BitTorrent::Torrent::Tracker
@@ -108,10 +89,8 @@ Incomplete: %d
 Number of URLs: %d
     %s
 END
-            $complete{refaddr $self},
-            $incomplete{refaddr $self},
-            scalar(@{$_urls{refaddr $self}}),
-            join qq[\r\n    ], map { $_->_url() } @{$_urls{refaddr $self}};
+            scalar(@{$urls{refaddr $self}}),
+            join qq[\r\n    ], map { $_->url() } @{$urls{refaddr $self}};
         return defined wantarray ? $dump : print STDERR qq[$dump\n];
     }
 
@@ -165,6 +144,19 @@ swarm.
 Returns the number of incomplete peers the tracker says are present in
 the swarm.
 
+=item C<urls()>
+
+Returns a list of related
+L<Net::BitTorrent::Torrent::Tracker::HTTP|Net::BitTorrent::Torrent::Tracker::HTTP>
+and L<Net::BitTorrent::Torrent::Tracker::UDP|Net::BitTorrent::Torrent::Tracker::UDP>
+objects.
+
+=item C<as_string ( [ VERBOSE ] )>
+
+Returns a 'ready to print' dump of the  object's data structure.  If
+called in void context, the structure is printed to C<STDERR>.
+C<VERBOSE> is a boolean value.
+
 =back
 
 =head1 Author
@@ -191,6 +183,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: Tracker.pm 34 2008-11-20 03:38:52Z sanko@cpan.org $
+=for svn $Id: Tracker.pm 56a7b7c 2009-01-27 02:13:14Z sanko@cpan.org $
 
 =cut
