@@ -162,7 +162,7 @@ l q[Exiting];
 
 =head1 NAME
 
-/tatoeba/002-debug.pl - Logs EVERYTHING to a file for debugging
+002-debug.pl - Demonstration script that logs EVERYTHING
 
 =head1 Description
 
@@ -198,6 +198,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: 002-debug.pl 56a7b7c 2009-01-27 02:13:14Z sanko@cpan.org $
+=for svn $Id: 002-debug.pl fac4ae0 2009-01-27 17:00:38Z sanko@cpan.org $
 
 =cut
