@@ -50,7 +50,7 @@ sub _percent_complete {
 
 =head1 NAME
 
-/tatoeba/004-resume.pl - Demonstration of Net::BitTorrent::Torrent's Resume System
+004-resume.pl - Demonstration of Net::BitTorrent::Torrent's Resume System
 
 =head1 Description
 
@@ -143,6 +143,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: 004-resume.pl 56a7b7c 2009-01-27 02:13:14Z sanko@cpan.org $
+=for svn $Id: 004-resume.pl fac4ae0 2009-01-27 17:00:38Z sanko@cpan.org $
 
 =cut
